Flask==0.10.1
Flask-Classy==0.6.8
Flask-Migrate==1.1.0
Flask-SQLAlchemy==1.0
Flask-Script==0.6.6
Jinja2==2.7.1
Mako==0.9.1
MarkupSafe==0.18
SQLAlchemy==0.9.0
Werkzeug==0.9.4
alembic==0.6.2
itsdangerous==0.23
psycopg2==2.5.1
inflect==0.2.4
